DockerSandbox

Struct DockerSandbox 

pub struct DockerSandbox { /* private fields */ }
Docker/Podman container sandbox

Implementations

Source

impl DockerSandbox

pub fn new(name: &str, runtime: ContainerRuntime) -> Self

Create a new Docker sandbox with the specified runtime

pub fn new_persistent(name: &str, runtime: ContainerRuntime) -> Self

Create a persistent Docker sandbox (won’t be cleaned up in Drop)

pub fn set_persistent(&mut self, persistent: bool)

Mark this sandbox as persistent (won’t be cleaned up in Drop)

pub fn with_detected_runtime(name: &str) -> Result<Self>

Create a new Docker sandbox with auto-detected runtime

Source

impl DockerSandbox

pub fn run_ephemeral_cmd( runtime: ContainerRuntime, image: &str, cmd: &[String], config: &SandboxConfig, ) -> Result<ExecResult>

Run a command in a temporary container using docker run --rm This is faster than create→start→exec→stop for one-shot commands