Module build

Module build 

Docker image building for custom Dockerfiles.

Provides functionality to build Docker images from Dockerfiles with caching support based on content hashing.

Structs

BuildResult
Result of a Docker build operation

Functions

build_image
Build a Docker image from a Dockerfile
build_or_use_image
Build image if Dockerfile exists, otherwise return the base image
image_exists
Check if a Docker image exists locally