pub fn is_host_allowed(host: &str, config: &ProxyConfig) -> boolExpand description
Check if a host is allowed by the proxy’s domain policy.
pub fn is_host_allowed(host: &str, config: &ProxyConfig) -> boolCheck if a host is allowed by the proxy’s domain policy.