Module rootfs

Module rootfs 

Docker image to ext4 rootfs conversion for Firecracker.

Converts Docker images built from Dockerfiles into ext4 rootfs images that can be used with Firecracker microVMs.

Structs

ConversionResult
Result of a rootfs conversion

Functions

convert_image_to_rootfs
Convert a Docker image to an ext4 rootfs for Firecracker
needs_conversion
Check if a rootfs conversion is needed for an image
rootfs_path_for_image
Get the rootfs path for an image (without converting)