pub struct DockerSandbox { /* private fields */ }Expand description
Docker/Podman container sandbox
Implementations
Sourceimpl DockerSandbox
impl DockerSandbox
Sourcepub fn new(name: &str, runtime: ContainerRuntime) -> Self
pub fn new(name: &str, runtime: ContainerRuntime) -> Self
Create a new Docker sandbox with the specified runtime
Sourcepub fn new_persistent(name: &str, runtime: ContainerRuntime) -> Self
pub fn new_persistent(name: &str, runtime: ContainerRuntime) -> Self
Create a persistent Docker sandbox (won’t be cleaned up in Drop)
Sourcepub fn set_persistent(&mut self, persistent: bool)
pub fn set_persistent(&mut self, persistent: bool)
Mark this sandbox as persistent (won’t be cleaned up in Drop)
Sourcepub fn with_detected_runtime(name: &str) -> Result<Self>
pub fn with_detected_runtime(name: &str) -> Result<Self>
Create a new Docker sandbox with auto-detected runtime
Sourceimpl DockerSandbox
impl DockerSandbox
Sourcepub fn run_ephemeral_cmd(
runtime: ContainerRuntime,
image: &str,
cmd: &[String],
config: &SandboxConfig,
) -> Result<ExecResult>
pub fn run_ephemeral_cmd( runtime: ContainerRuntime, image: &str, cmd: &[String], config: &SandboxConfig, ) -> Result<ExecResult>
Run a command in a temporary container using docker run --rm
This is faster than create→start→exec→stop for one-shot commands