Docker image to ext4 rootfs conversion for Firecracker.
Converts Docker images built from Dockerfiles into ext4 rootfs images that can be used with Firecracker microVMs.
Structs
- Conversion
Result - Result of a rootfs conversion
Functions
- convert_
image_ to_ rootfs - Convert a Docker image to an ext4 rootfs for Firecracker
- needs_
conversion - Check if a rootfs conversion is needed for an image
- rootfs_
path_ for_ image - Get the rootfs path for an image (without converting)